Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2447)

Unified Diff: webrtc/p2p/base/fakepackettransport.h

Issue 2679103006: Rename "PacketTransportInterface" to "PacketTransportInternal". (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/p2p/base/fakeicetransport.h ('k') | webrtc/p2p/base/icetransportinternal.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/p2p/base/fakepackettransport.h
diff --git a/webrtc/p2p/base/fakepackettransport.h b/webrtc/p2p/base/fakepackettransport.h
index c8fc9bb1e99ad82d7c97f1e4fbb1e7cf75b41890..03966f9ca06c967029f57aaa4374a090eb97d028 100644
--- a/webrtc/p2p/base/fakepackettransport.h
+++ b/webrtc/p2p/base/fakepackettransport.h
@@ -15,12 +15,12 @@
#include "webrtc/base/asyncinvoker.h"
#include "webrtc/base/copyonwritebuffer.h"
-#include "webrtc/p2p/base/packettransportinterface.h"
+#include "webrtc/p2p/base/packettransportinternal.h"
namespace rtc {
// Used to simulate a packet-based transport.
-class FakePacketTransport : public PacketTransportInterface {
+class FakePacketTransport : public PacketTransportInternal {
public:
explicit FakePacketTransport(const std::string& debug_name)
: debug_name_(debug_name) {}
@@ -57,7 +57,7 @@ class FakePacketTransport : public PacketTransportInterface {
}
}
// Fake PacketTransportInterface implementation.
std::string debug_name() const override { return debug_name_; }
bool writable() const override { return writable_; }
bool receiving() const override { return receiving_; }
@@ -57,7 +57,7 @@ class FakePacketTransport : public PacketTransportInterface {
}
}
- // Fake PacketTransportInterface implementation.
+ // Fake PacketTransportInternal implementation.
std::string debug_name() const override { return debug_name_; }
bool writable() const override { return writable_; }
« no previous file with comments | « webrtc/p2p/base/fakeicetransport.h ('k') | webrtc/p2p/base/icetransportinternal.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698